@@ -5,7 +5,7 @@ package Template::Tiny;
 use 5.00503;
 use strict;
 
-$Template::Tiny::VERSION = '0.11';
+$Template::Tiny::VERSION = '1.12';
 
 # Evaluatable expression
 my $EXPR = qr/ [a-z_][\w.]* /xs;
@@ -72,6 +72,14 @@ sub new {
 	bless { @_[1..$#_] }, $_[0];
 }
 
+# Copy and modify
+sub preprocess {
+	my $self = shift;
+	my $text = shift;
+	$self->_preprocess(\$text);
+	return $text;
+}
+
 sub process {
 	my $self  = shift;
 	my $copy  = ${shift()};
@@ -81,7 +89,7 @@ sub process {
 	local $^W = 0;
 
 	# Preprocess to establish unique matching tag sets
-	$self->_preparse( \$copy );
+	$self->_preprocess( \$copy );
 
 	# Process down the nested tree of conditions
 	my $result = $self->_process( $stash, $copy );
@@ -96,9 +104,16 @@ sub process {
 	}
 }
 
+
+
+
+
+######################################################################
+# Support Methods
+
 # The only reason this is a standalone is so we can
 # do more in-depth testing.
-sub _preparse {
+sub _preprocess {
 	my $self = shift;
 	my $copy = shift;
 
@@ -210,19 +225,16 @@ Template::Tiny - Template Toolkit reimplemented in as little code as possible
 
 =head1 DESCRIPTION
 
-B<WARNING: THIS MODULE IS EXPERIMENTAL AND SUBJECT TO CHANGE WITHOUT NOTICE>
-
-B<YOU HAVE BEEN WARNED!>
-
-B<Template::Tiny> is a reimplementation of a partial subset of the
+B<Template::Tiny> is a reimplementation of a subset of the functionality from
 L<Template> Toolkit in as few lines of code as possible.
 
 It is intended for use in light-usage, low-memory, or low-cpu templating
 situations, where you may need to upgrade to the full feature set in the
-future, or if you want the familiarity of TT-style templates.
+future, or if you want the retain the familiarity of TT-style templates.
 
-It is intended to have fully-compatible template and stash usage,
-with a limited by similar Perl API.
+For the subset of functionality it implements, it has fully-compatible template
+and stash API. All templates used with B<Template::Tiny> should be able to be
+transparently upgraded to full Template Toolkit.
 
 Unlike Template Toolkit, B<Template::Tiny> will process templates without a
 compile phase (but despite this is still quicker, owing to heavy use of
@@ -232,29 +244,34 @@ the Perl regular expression engine.
 
 Only the default C<[% %]> tag style is supported.
 
-Both the [%+ +%] style explicit whitespace and the [%- -%] style explicit
-chomp are support, although the [%+ +%] version is unneeded as Template::Tiny
-does not support default-enabled PRE_CHOMP or POST_CHOMP.
+Both the C<[%+ +%]> style explicit whitespace and the C<[%- -%]> style
+explicit chomp B<are> support, although the C<[%+ +%]> version is unneeded
+in practice as B<Template::Tiny> does not support default-enabled C<PRE_CHOMP>
+or C<POST_CHOMP>.
 
-Variable expressions in the form foo.bar.baz are supported.
+Variable expressions in the form C<[% foo.bar.baz %]> B<are> supported.
 
-Appropriate simple behaviours for ARRAY reference, HASH reference and objects
-are supported, but not "VMethods" such as array lengths.
+Appropriate simple behaviours for C<ARRAY> references, C<HASH> references and
+objects are supported. "VMethods" such as [% array.length %] are B<not>
+supported at this time.
 
-IF, ELSE and UNLESS conditions are supported, but only with simple foo.bar.baz
-conditions.
+C<IF>, C<ELSE> and C<UNLESS> conditional blocks B<are> supported, but only with
+simple C<[% foo.bar.baz %]> conditions.
 
-Support for looping is available, in the most simple [% FOREACH item IN list %]
-form.
+Support for looping (or rather iteration) is available in simple
+C<[% FOREACH item IN list %]> form B<is> supported. Other loop structures are
+B<not> supported. Because support for arbitrary or infinite looping is not
+available, B<Template::Tiny> templates are not turing complete. This is
+intentional.
 
-All four IF/ELSE/UNLESS/FOREACH control structures are able to be nested to
-arbitrary depth.
+All of the four supported control structures C<IF>/C<ELSE>/C<UNLESS>/C<FOREACH>
+can be nested to arbitrary depth.
 
-The treatment of C<_private> hash and method keys is compatible with Template
-Toolkit, returning null or false rather than the actual content of the hash key
-or method.
+The treatment of C<_private> hash and method keys is compatible with
+L<Template> Toolkit, returning null or false rather than the actual content
+of the hash key or method.
 
-Anything beyond this is currently out of scope
+Anything beyond the above is currently out of scope.
 
 =head1 METHODS
 
@@ -273,7 +290,7 @@ Additional parameters can be provided without error, but will be ignored.
 
 =head2 process
 
-  # DEPRECATED: Return template results
+  # DEPRECATED: Return template results (emits a warning)
   my $text = $template->process( \$input, $vars );
   
   # Print template results to STDOUT
@@ -285,19 +302,19 @@ Additional parameters can be provided without error, but will be ignored.
 
 The C<process> method is called to process a template.
 
-The first parameter is a reference to a text string containing the
-template text. A reference to a hash may be passed as the second
-parameter containing definitions of template variables.
+The first parameter is a reference to a text string containing the template
+text. A reference to a hash may be passed as the second parameter containing
+definitions of template variables.
 
 If a third parameter is provided, it must be a scalar reference to be
 populated with the output of the template.
 
-For a limited amount of time, the old deprecated interface will continue
-to be supported. If C<process> is called without a third parameter, and in
+For a limited amount of time, the old deprecated interface will continue to
+be supported. If C<process> is called without a third parameter, and in
 scalar or list contest, the template results will be returned to the caller.
 
 If C<process> is called without a third parameter, and in void context, the
-template results will be print()ed to the currently selected file handle
+template results will be C<print()>ed to the currently selected file handle
 (probably C<STDOUT>) for compatibility with L<Template>.
 
 =head1 SUPPORT
@@ -314,11 +331,11 @@ Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 SEE ALSO
 
-L<Config::Simple>
+L<Config::Tiny>, L<CSS::Tiny>, L<YAML::Tiny>
 
 =head1 COPYRIGHT
 
-Copyright 2009 - 2010 Adam Kennedy.
+Copyright 2009 - 2011 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
